[−][src]Module allocator_suite::allocators
Allocators.
Modules
| allocator | |
| binary_search_trees | There are various kinds of binary search tree available suitable for storing a free list of free blocks. |
| bit_set | A bit set based allocator; allows reallocations, but requires a linear scan to find free blocks. |
| bump_allocator | |
| context_allocator | |
| global | Global, switchable allocator. |
| memory_map_allocator | |
| multiple_binary_search_tree_allocator | |
| prelude |