[−][src]Module allocator_suite::allocators::global::local_allocator
Traits
| LocalAllocator | A local allocator is an allocator with a known range of memory addresses it uses for allocated memory. |
| LocalAllocator | A local allocator is an allocator with a known range of memory addresses it uses for allocated memory. |